==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Esborrar les estadístiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolució de les visites<br />@visites@ visites',
	'icone_repartition_actuelle' => 'Mostrar la distribució actual',
	'icone_repartition_visites' => 'Repartiment de les visites',
	'icone_statistiques_visites' => 'Estadístiques',
	'info_affichier_visites_articles_plus_visites' => 'Mostrar les visites pels <b>articles més visitats des del començament:</b>',
	'info_comment_lire_tableau' => 'Com llegir aquest quadre',
	'info_forum_statistiques' => 'Estadístiques de les visites',
	'info_popularite_2' => 'popularitat del lloc:',
	'info_popularite_3' => 'popularitat: @popularite@ ; visites: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_question_vignettes_referer' => 'Quan consulteu les estadístiques, podeu visualitzar una estimació dels llocs d’origen de les visites',
	'info_question_vignettes_referer_oui' => 'Mostrar les captures dels llocs d’origen de les visites',
	'info_visites' => 'visites:',
	'info_visites_plus_populaires' => 'Mostrar les visites pels <b>articles més populars</b> i pels <b>últims articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gestionar les estadístiques', # MODIF

	// O
	'onglet_origine_visites' => 'Origen de les visites',
	'onglet_repartition_debut' => 'des del començament',
	'onglet_repartition_lang' => 'Repartiment per llengües',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Aquesta ordre esborra totes les dades lligades a les estadístiques de visita del lloc, fins i tot la popularitat dels articles.',
	'texte_comment_lire_tableau' => 'El rang de l’article, dins de la classificació per popularitat, està indicat al marge; la popularitat de l’article (una estimació del nombre de visites quotidianes que rebrà l’article si es manté el ritme actual de consultes) i el nombre de visites rebudes des que va estar per primer cop en línia estàn visibles al menú que apareix quan passem el ratolí per sobre del títol.',
	'texte_signification' => 'Les columnes fosques representen les entrades acumulades (total de les subseccions), les columnes clares el número de visites per a cada secció.',
	'titre_evolution_visite' => 'Evolució de les visites',
	'titre_liens_entrants' => 'Enllaços entrants',
	'titre_page_statistiques' => 'Estadistiques per seccions',
	'titre_page_statistiques_visites' => 'Estatistiques de les visites'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Esborrar les estadístiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolució de les visites<br />@visites@ visites',
	'icone_repartition_actuelle' => 'Mostrar la distribució actual',
	'icone_repartition_visites' => 'Repartiment de les visites',
	'icone_statistiques_visites' => 'Estadístiques',
	'info_affichier_visites_articles_plus_visites' => 'Mostrar les visites pels <b>articles més visitats des del començament:</b>',
	'info_comment_lire_tableau' => 'Com llegir aquest quadre',
	'info_forum_statistiques' => 'Estadístiques de les visites',
	'info_popularite_2' => 'popularitat del lloc:',
	'info_popularite_3' => 'popularitat: @popularite@ ; visites: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_question_vignettes_referer' => 'Quan consulteu les estadístiques, podeu visualitzar una estimació dels llocs d’origen de les visites', # MODIF
	'info_question_vignettes_referer_oui' => 'Mostrar les captures dels llocs d’origen de les visites',
	'info_visites' => 'visites:',
	'info_visites_plus_populaires' => 'Mostrar les visites pels <b>articles més populars</b> i pels <b>últims articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gestionar les estadístiques', # MODIF

	// O
	'onglet_origine_visites' => 'Origen de les visites',
	'onglet_repartition_debut' => 'des del començament',
	'onglet_repartition_lang' => 'Repartiment per llengües',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Aquesta ordre esborra totes les dades lligades a les estadístiques de visita del lloc, fins i tot la popularitat dels articles.',
	'texte_comment_lire_tableau' => 'El rang de l’article, dins de la classificació per popularitat, està indicat al marge; la popularitat de l’article (una estimació del nombre de visites quotidianes que rebrà l’article si es manté el ritme actual de consultes) i el nombre de visites rebudes des que va estar per primer cop en línia estàn visibles al menú que apareix quan passem el ratolí per sobre del títol.',
	'texte_signification' => 'Les columnes fosques representen les entrades acumulades (total de les subseccions), les columnes clares el número de visites per a cada secció.',
	'titre_evolution_visite' => 'Evolució de les visites',
	'titre_liens_entrants' => 'Enllaços entrants',
	'titre_page_statistiques' => 'Estadistiques per seccions',
	'titre_page_statistiques_visites' => 'Estatistiques de les visites'
);
